#
# pg_profile::database::db_clusters
#
# @summary This class implements the steps to initialize the database for the foirst time.
#
#
# @param [Hash] dirs
#    The directory your want to ensure before creating the Postgres clusters.
#
# @param [Hash] list
#    A Hash of Postgres clusters to be managed by Puppet.
#
#
# See the file "LICENSE" for the full license governing this code.
#
class pg_profile::database::db_clusters (
  Hash  $dirs,
  Hash  $list,
) inherits pg_profile {
  echo { "Ensure Postgres cluster(s) at ${list.keys.join(',')}":
    withpath => false,
  }
  easy_type::debug_evaluation() # Show local variable on extended debug
  $dirs.each |$dir, $props| {
    file { $dir:
      *      => $props,
      before => Pg_cluster[$list.keys],
    }
  }

  create_resources('pg_cluster', $list, { 'ensure' => 'present' })
}
